@@ -73,15 +73,15 @@ def conv_confirm_f(s: str) -> Callable:
 def get_real_filename(path: str) -> str:
     path = str(Path(path).expanduser())
 
-    if not Path(path).exists():
-        while path.startswith("_"):
-            path = path[1:]
+    if Path(path).exists():
+        return path
 
-        path = str(
-            pathlib.Path(__file__).parent.absolute().joinpath("assets").joinpath(
-                "musics").joinpath(path))
+    while path.startswith("_"):
+        path = path[1:]
 
-    return path
+    return str(
+        pathlib.Path(__file__).parent.absolute().joinpath("assets").joinpath("musics").joinpath(
+            path))
 
 
 @dataclass
