@@ -27,7 +27,9 @@ def get_real_json_filename(path: str) -> str:
 
     while path.startswith("_"):
         path = path[1:]
-    path = str(pathlib.Path(__file__).parent.parent.absolute().joinpath("examples").joinpath(path))
+    path = str(
+        pathlib.Path(__file__).parent.absolute().joinpath("assets").joinpath("clocks").joinpath(
+            path))
 
     return path
 
